ClashMode class

The Clash routing mode constants.

Constructors

ClashMode()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

block → const String
Block the traffic.
direct → const String
Bypass the proxy and connect directly.
global → const String
Route all traffic through the proxy.
rule → const String
Route traffic according to rules.