ClientGroup class

Represents a proxy group in the sing-box client.

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ClientGroup({required String tag, required String type, required bool selectable, required String selected, required bool isExpand, List<ClientGroupItem>? items})
Creates a new ClientGroup instance.
ClientGroup.fromJson(Map<String, dynamic> json)
Creates a new ClientGroup instance from a JSON map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isExpand bool
Whether the group is expanded in the UI.
getter/setter pair
items List<ClientGroupItem>?
The list of items (proxies or other groups) in this group.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectable bool
Whether the group allows selecting a specific proxy.
getter/setter pair
selected String
The tag of the currently selected proxy in this group.
getter/setter pair
tag String
The tag of the group.
final
type String
The type of the group (e.g., 'selector', 'urltest').
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this ClientGroup instance to a JSON map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited