DioClient class

User-Agent 格式说明:APP名称/APP版本 (编译版本好; 平台 系统版本; 内核名称/内核版本)

Constructors

DioClient()
Creates the singleton DioClient instance.
factory

Properties

allowBadCertificates ↔ bool
是否放行证书校验失败的 HTTPS 连接。
getter/setter pair
dio → Dio
The configured Dio instance.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited