flutter_sing_box library
Classes
-
ApiResult<
T> - The result of a network request, holding the decoded data and headers.
- AssetUtil
- Base64Provider
- Decodes a Base64-encoded subscription into a list of Outbounds.
- CacheFile
- Clash
- ClashApi
- ClashGroup
- ClashGroupType
- ClashMode
- The Clash routing mode constants.
- ClashProvider
- Converts a Clash-format subscription into a list of Outbounds.
- ClashProxy
- ClashProxyType
- ClientClashMode
- Represents the available and current Clash modes.
- ClientGroup
- Represents a proxy group in the sing-box client.
- ClientGroupItem
- Represents an item within a proxy group.
- ClientLog
- ClientStatus
- Represents the status of the sing-box client.
- CsSettingsStorage
- DioClient
- User-Agent 格式说明:APP名称/APP版本 (编译版本好; 平台 系统版本; 内核名称/内核版本)
- Dns
- DnsRule
- Experimental
- FlutterSingBox
- The main class for interacting with the flutter_sing_box plugin.
- FlutterSingBoxConstants
- Shared constant values used across the flutter_sing_box plugin.
- FlutterSingBoxWindows
- HelperConfig
- HttpProxy
- Inbound
- InboundType
- KeyValueStorage
- 键值存储抽象接口,解耦 MMKV 原生依赖以支持单元测试。
- Log
- MemoryStorage
- 纯 Dart 内存存储,用于单元测试,零原生依赖。
- MethodChannelFlutterSingBox
- An implementation of FlutterSingBoxPlatform that uses method channels.
- MmkvStorage
- 基于 MMKV 的键值存储实现。
- Multiplex
- NetworkService
- Fetches subscription content over the network.
- Obfs
- Outbound
- OutboundPacketEncoding
- The packet encoding mode constants for outbounds.
- OutboundSecurity
- The transport security mode constants for outbounds.
- OutboundTransportType
- The transport protocol type constants for outbounds.
- OutboundType
- The sing-box outbound type constants.
- Platform
- PluginOpts
- Profile
- ProfileService
- Example: content-disposition: attachment;filename*=UTF-8''%E7%8B%97%E7%8B%97%E5%8A%A0%E9%80%9F.com profile-title: base64:5LiJ5q+b5py65Zy6 profile-update-interval: 24 profile-web-page-url: https://panel.dg5.biz subscription-userinfo: upload=8761515695; download=60139076905; total=214748364800; expire=1777514961 content-type: text/html; charset=UTF-8
- ProfileStorage
- ProxyStarted
- 已启动。
- ProxyStarting
- 正在启动。
- ProxyState
- 代理(VPN)服务的生命周期状态。
- ProxyStopped
- 已停止。
- ProxyStopping
- 正在停止。
- Reality
- Reality TLS 配置(VLESS Reality 所需)。
- RealityOpts
- Realm
- 自 sing-box 1.14.0 起 通过 Hysteria Realm 会合服务连接 Hysteria2 服务器。
- RealmOpts
- RealmPortMapping
- Route
- RouteRule
- RuleAction
- The action constants applied to a matched routing rule.
- RuleSet
- Server
- SingBox
- SingBoxConfigProvider
- Builds a normalized SingBox config from raw subscription content.
- SingBoxSchemaValidator
- 校验 sing-box 配置是否符合官方 JSON Schema(draft 2020-12)。
- Tls
- Transport
- V2Ray 传输层 V2Ray Transport 是 v2ray 发明的一组私有协议,并污染了其他协议的名称,如 clash 中的 trojan-grpc。
- TypedProfile
- UdpOverTcp
- UserInfo
- Utls
Enums
- ProfileType
- The type of a subscription profile.
- ProxyMode
- Windows 桌面端的代理模式。
- ValidationErrorType
- Enum representing the types of validation failures when checking data against a schema.
- WindowsServiceStatus
-
Windows 端
clash_sing_service系统服务的可观测状态。
Extension Types
- ValidationError
- A validation error with detailed information about the location of the error.
Extensions
- ClashGroupExt on ClashGroup
- Extensions for converting a ClashGroup into an Outbound.
- ClashProxyExt on ClashProxy
- Extensions for converting a ClashProxy into an Outbound. TODO: 待实现 snell
- ClientGroupItemPatterns on ClientGroupItem
- Adds pattern-matching-related methods to ClientGroupItem.
- YamlMapExt on YamlMap
Constants
- windowsServiceDescription → const String
- Windows 系统服务描述。
- windowsServiceDisplayName → const String
- Windows 系统服务展示名。
- windowsServiceName → const String
-
Windows 系统服务名(与
clash_sing_helper.exe注册的服务一致)。
Functions
-
toSingBoxServerPorts(
String? ports) → List< String> ? - 端口跳跃语法转 sing-box server_ports 列表。
Typedefs
-
AssetBytesWriter
= Future<
void> Function(Uint8List bytes, File dest) -
字节写入函数签名:把
bytes写入dest。便于单测注入模拟异常。 -
AssetFileRenamer
= Future<
File> Function(File source, String newPath) -
文件重命名函数签名:把
source重命名为newPath。便于单测注入模拟异常。