FlutterSingBox class
The main class for interacting with the flutter_sing_box plugin.
Constructors
Properties
-
clashModeStream
→ Stream<
ClientClashMode> -
A stream of client Clash mode updates.
no setter
-
connectedStatusStream
→ Stream<
ClientStatus> -
A stream of client connection status updates.
no setter
-
groupStream
→ Stream<
List< ClientGroup> > -
A stream of client group updates.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
logStream
→ Stream<
List< ClientLog> > -
A stream of log messages from the sing-box core.
no setter
-
proxyStateStream
→ Stream<
ProxyState> -
A stream of proxy state updates.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getSingBoxVersion(
) → Future< String> - Gets the version of the underlying sing-box core.
-
init(
) → Future< void> - Initializes the plugin.
-
installService(
{required String serviceName, required String displayName, required String description}) → Future< bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryServiceStatus(
) → Future< WindowsServiceStatus> -
查询 Windows 端
clash_sing_service的安装/运行状态。 -
selectOutbound(
{required String groupTag, required String outboundTag}) → Future< void> - Selects an outbound for a specific group.
-
serviceReload(
) → Future< void> - Reloads the service configuration.
-
setClashMode(
String clashMode) → Future< void> - Sets the Clash mode.
-
setGroupExpand(
{required String groupTag, required bool isExpand}) → Future< void> - Sets the expansion state of a group in the UI.
-
startService(
) → Future< bool> - 启动已安装的 Windows 系统服务。
-
startVpn(
) → Future< void> - Starts the VPN service.
-
stopService(
) → Future< bool> - 停止 Windows 系统服务。
-
stopVpn(
) → Future< void> - Stops the VPN service.
-
toString(
) → String -
A string representation of this object.
inherited
-
uninstallService(
) → Future< bool> - 卸载 Windows 系统服务。
-
urlTest(
{required String groupTag}) → Future< void> - Performs a URL test for a specific group.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited